@@ -1,60 +1,48 @@
 package Test::Mocha::Mock;
 {
-  $Test::Mocha::Mock::VERSION = '0.13';
+  $Test::Mocha::Mock::VERSION = '0.14';
 }
 # ABSTRACT: Mock objects
 
-use Moose;
-use namespace::autoclean;
+use strict;
+use warnings;
 
 use Carp qw( croak );
-
-use aliased 'Test::Mocha::Invocation';
-use aliased 'Test::Mocha::Stub';
-
+use Test::Mocha::MethodCall;
 use Test::Mocha::Types qw( Matcher );
-use Test::Mocha::Util qw(
-    extract_method_name
-    get_attribute_value
-    has_caller_package
-);
-
-use Types::Standard qw( ArrayRef InstanceOf Int Map Str );
+use Test::Mocha::Util qw( extract_method_name get_attribute_value
+                          has_caller_package );
+use Types::Standard qw( Str );
 use UNIVERSAL::ref;
 
 our $AUTOLOAD;
 
+# Attributes:
+#
 # class
 # The name of the class that the object is pretending to be blessed into.
-# Calling C<ref()> on the mock object (either as a method or as a function)
-# will return this class name.
-
-has 'class' => (
-    isa => Str,
-    reader => 'ref',
-    default => __PACKAGE__,
-);
 
 # calls
 # An array reference containing a record of all methods called on this mock
 # to be used for verification.
 
-has 'calls' => (
-    isa => ArrayRef[InstanceOf[Invocation]],
-    is => 'bare',
-    default => sub { [] }
-);
-
 # stubs
 # Contains all of the methods stubbed for this mock. It maps the method name
 # to an array of stubs. Stubs are matched against invocation arguments to
 # determine which stub to dispatch to.
 
-has 'stubs' => (
-    isa => Map[ Str, ArrayRef[InstanceOf[Stub]] ],
-    is => 'bare',
-    default => sub { {} }
-);
+sub new {
+    # uncoverable pod
+    my ($class, %args) = @_;
+    ### assert: !defined $args{class} || Str->check( $args{class} )
+
+    my $self = \%args;
+    $self->{class} = __PACKAGE__ unless defined $self->{class};
+    $self->{calls} = [];
+    $self->{stubs} = {};
+
+    return bless $self, $class;
+}
 
 sub AUTOLOAD {
     my $self = shift;
@@ -66,9 +54,9 @@ sub AUTOLOAD {
         unless @invalid_args == 0;
 
     # record the method call for verification
-    my $method_call = Invocation->new(
+    my $method_call = Test::Mocha::MethodCall->new(
         name => $method_name,
-        args => \@_,
+        args => [@_],
     );
 
     my $calls = get_attribute_value($self, 'calls');
@@ -106,10 +94,19 @@ sub isa {
 # is required.
 
 sub does {
-    return if has_caller_package('UNIVERSAL::ref');
+    # uncoverable pod
     return 1;
 }
 
+# ref()
+# Returns the name of the class that this object is pretending to be.
+# C<ref()> can be called either as a method or as a function.
+
+sub ref {
+    # uncoverable pod
+    return $_[0]->{class};
+}
+
 # can()
 # Always returns a reference to the C<AUTOLOAD()> method. It allows the mock
 # object to C<can()> do any method that is required.
@@ -123,5 +120,4 @@ sub can {
     };
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
