@@ -1,6 +1,6 @@
 package Test::Mocha::Util;
 {
-  $Test::Mocha::Util::VERSION = '0.13';
+  $Test::Mocha::Util::VERSION = '0.14';
 }
 # ABSTRACT: Internal utility functions for Test::Mocha
 
@@ -11,9 +11,9 @@ use warnings;
 use 5.010001;
 use experimental qw( smartmatch );
 
+use Carp qw( confess );
 use Exporter qw( import );
 use Scalar::Util qw( blessed looks_like_number refaddr );
-use Moose::Util qw( find_meta );
 
 our @EXPORT_OK = qw(
     extract_method_name
@@ -47,9 +47,11 @@ sub get_attribute_value {
     # uncoverable pod
     my ($object, $attribute) = @_;
 
-    return find_meta($object)
-        ->find_attribute_by_name($attribute)
-        ->get_value($object);
+    # uncoverable branch true
+    confess "Attribute '$attribute' does not exist for object '$object'"
+        if not defined $object->{$attribute};
+
+    return $object->{$attribute};
 }
 
 # has_caller_package
